@@ -18,9 +18,10 @@ int calc_codon_number(char* codon);
 char codaa(char* codon, int code);
 int get_ncbi_gc_number(int gc);
 int get_acnuc_gc_number(int ncbi_gc);
-int strcmptrail(char *s1, int l1, char *s2, int l2);
-void majuscules(char *name);
-void compact(char *chaine);
+int strcmptrail(char* s1, int l1, char* s2, int l2);
+void majuscules(char* name);
+void compact(char* chaine);
+void* mycalloc(int nbr, size_t taille);
 char complementer_base(char nucl);
 void complementer_seq(char* deb_ch, int l);
 char init_codon_to_aa(char* codon, int gc);
@@ -34,11 +35,11 @@ void gets_no_echo(char* password, size_t lpw);
 int trim_key(char* name) /* remove trailing spaces */
 {
   char* p;
-  int l = strlen(name);
+  int l = (int)strlen(name);
   p = name + l - 1;
   while (p >= name && *p == ' ')
     *(p--) = 0;
-  return (p + 1) - name;
+  return (int)((p + 1) - name);
 }
 
 
@@ -47,14 +48,14 @@ void padtosize(char* pname, char* name, int length)
   int i;
   strncpy(pname, name, length);
   pname[length] = 0;
-  for (i = strlen(pname); i < length; i++)
+  for (i = (int)strlen(pname); i < length; i++)
   {
     pname[i] = ' ';
   }
 }
 
 
-#define TOTCODES 18  /* nbre total de codes definis, 0 inclus */
+#define TOTCODES 19  /* nbre total de codes definis, 0 inclus */
 int totcodes = TOTCODES;
 
 char aminoacids[] = "RLSTPAGVKNQHEDYCFIMW*X";
@@ -303,6 +304,19 @@ struct genetic_code_libel genetic_code[TOTCODES] =
           0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
           0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 19, 0} /* UUG */
   }
+  ,
+  { /* 18: Candidate Division SR1 and Gracilibacteria */
+    {"UGA=G"},
+    /*ANN*/ {9, 10, 9, 10, 4, 4, 4, 4, 1, 3, 1, 3, 18, 18, 19, 18,
+             /*CNN*/ 11, 12, 11, 12, 5, 5, 5, 5, 1, 1, 1, 1, 2, 2, 2, 2,
+             /*GNN*/ 13, 14, 13, 14, 6, 6, 6, 6, 7, 7, 7, 7, 8, 8, 8, 8,
+             /*TNN*/ 21, 15, 21, 15, 3, 3, 3, 3, 7, 16, 20, 16, 2, 17, 2, 17, 22},
+    /*ncbi*/ 25,
+    /*init*/ {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 19, 0, /* AUG */
+              0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 19, 0, /* CUG */
+              0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
+              0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 19, 0} /* UUG */
+  }
 
 
 /*       1         2
@@ -342,7 +356,7 @@ int calc_codon_number(char* codon)
       break;
     }
     else
-      base = (p - nucleotides) / 2;
+      base = (int)(p - nucleotides) / 2;
     num = num * 4 + nucnum[base];
     codon++;
   }
@@ -400,12 +414,12 @@ int strcmptrail(char* s1, int l1, char* s2, int l2)
   if (l1 > 0)
   {
     if ( (fin = (char*)memchr(s1, 0, l1) ) != NULL)
-      l1 = fin - s1;
+      l1 = (int)(fin - s1);
   }
   if (l2 > 0)
   {
     if ( (fin = (char*)memchr(s2, 0, l2) ) != NULL)
-      l2 = fin - s2;
+      l2 = (int)(fin - s2);
   }
 
   if (l2 > l1)
@@ -446,7 +460,7 @@ void compact(char* chaine)
   int l;
   char* p, * q;
 
-  l = strlen(chaine); p = chaine + l;
+  l = (int)strlen(chaine); p = chaine + l;
   while (*(--p) == ' ' && p >= chaine)
     *p = 0;
   while ((p = strchr(chaine, ' ')) != NULL)
@@ -454,7 +468,7 @@ void compact(char* chaine)
     q = p + 1;
     while (*q == ' ')
       q++;
-    l = q - p;
+    l = (int)(q - p);
     while (*q != 0)
     {
       *(q - l) = *q; q++;
@@ -464,6 +478,20 @@ void compact(char* chaine)
 }
 
 
+void* mycalloc(int nbre, size_t size)
+{
+  void* point;
+
+  point = calloc(nbre, size);
+  if (point == NULL)
+  {
+    fprintf(stderr, "Error: problem allocating memory.\n");
+    exit(1);
+  }
+  return point;
+}
+
+
 char complementer_base(char nucl)
 {
   switch (nucl)
@@ -602,7 +630,7 @@ int compch(char* cible, int lcible, char** posmot, int nbrmots)
   pos = cible + lcible - 1;
   while (pos >= cible && *pos == ' ')
     pos--;
-  lcible = pos - cible + 1;
+  lcible = (int)(pos - cible + 1);
   memcpy(vcible, cible, lcible);
   vcible[lcible] = 0;
   cible = vcible;
@@ -613,7 +641,7 @@ int compch(char* cible, int lcible, char** posmot, int nbrmots)
 
   if (posmot[0] != NULL)   /* comparaison avec mot initial */
   {
-    l = strlen(posmot[0]);
+    l = (int)strlen(posmot[0]);
     if (strncmp(cible, posmot[0], l) != 0)
       return 0;
     cible += l;
@@ -625,14 +653,14 @@ int compch(char* cible, int lcible, char** posmot, int nbrmots)
     pos = strstr(cible, posmot[num]);
     if (pos == NULL)
       return 0;
-    l = strlen(posmot[num]);
+    l = (int)strlen(posmot[num]);
     cible = pos + l;
     num++;
   }
   if (total == nbrmots - 1)
     return 1;  /* template se termine par @ */
 /* test si cible se termine par dernier mot du template */
-  l = strlen(posmot[nbrmots - 1]);
+  l = (int)strlen(posmot[nbrmots - 1]);
   if (strcmp(vcible + lcible - l, posmot[nbrmots - 1]) == 0)
     return 1;
   return 0;
@@ -750,5 +778,3 @@ void gets_no_echo(char* password, size_t lpw)
 #endif
   return;
 }
-
-
